# ccode
copyright by author: Mohammed Hamza
The date the library was established : 2023/3/13

Description of the library :
A library that encodes and runs any script that has been encrypted through the library in order to preserve the confidentiality of the code and preserve it from theft and preserve the programming rights of the programmer. The Lib99 library is a library that specializes in encryption and uses several offices inside it and uses a special type of encryption that was programmed in 2023 month The third on the 13th
and u need install pycryptodome library using pip install pycryptodome command

Functions that can be used within the library:
encode:
to encrypt the code

launch:
In order to run the code and maintain its confidentiality
